import { forwardRef, useState } from "react";
import styled, { css } from "styled-components";
import { Flex } from "./flex";
import { Box } from "./box";
import { VisuallyHidden } from "./visually-hidden";
import { CloseIcon, InfoIcon, CheckIcon, ErrorIcon, WarningIcon } from "../icons";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const PrefixIcon = styled.div.withConfig({
  displayName: "alert__PrefixIcon",
  componentId: "sc-1ojw698-0"
})(["display:inline-flex;flex-shrink:0;font-size:24px;"]);
const CloseButton = styled.button.withConfig({
  displayName: "alert__CloseButton",
  componentId: "sc-1ojw698-1"
})(["width:24px;height:24px;font-size:24px;padding:0;display:flex;align-self:flex-start;justify-content:center;align-items:center;flex-shrink:0;background-color:transparent;border-radius:", "px;border:none;transition:box-shadow 0.2s,background 0.2s;outline:0;cursor:pointer;&:active,&:focus{box-shadow:0 0 0 2px ", ";}"], p => p.theme.radii.base, p => p.theme.colors.primary[2]);
const makeTypeColor = (type, color) => p => p.type === type && css(["background-color:", ";border:2px solid ", ";", "{color:", ";}&,", " svg{color:", ";}", ":hover{background-color:", ";}"], p.theme.colors[color][0], p.theme.colors[color][2], PrefixIcon, p.theme.colors[color].base, CloseButton, p.theme.colors[color][7], CloseButton, p.theme.colors[color][1]);
const StyledAlert = styled(Flex).withConfig({
  displayName: "alert__StyledAlert",
  componentId: "sc-1ojw698-2"
})(["position:relative;align-items:center;padding:", "px;gap:", "px;border-radius:", "px;font-size:", "px;line-height:", ";color:", ";", " ", " ", " ", " ", ""], p => p.theme.space.sm, p => p.theme.space.sm, p => p.theme.radii.base, p => p.theme.fontSizes.md, p => p.theme.lineHeights.base, p => p.theme.colors.heading, makeTypeColor("info", "info"), makeTypeColor("success", "success"), makeTypeColor("error", "danger"), makeTypeColor("warning", "warning"), p => p.banner && css(["border:0;border-radius:0;"]));
const iconMap = {
  info: /*#__PURE__*/_jsx(InfoIcon, {}),
  success: /*#__PURE__*/_jsx(CheckIcon, {}),
  error: /*#__PURE__*/_jsx(ErrorIcon, {}),
  warning: /*#__PURE__*/_jsx(WarningIcon, {})
};
export const Alert = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    type = "info",
    message,
    banner = false,
    icon,
    closable = false,
    onClose,
    color,
    ...rest
  } = _ref;
  const [closed, setClosed] = useState(false);
  const iconNode = icon ?? iconMap[type];
  const handleClose = event => {
    event.preventDefault();
    setClosed(true);
    onClose?.(event);
  };
  if (closed) {
    return null;
  }
  return /*#__PURE__*/_jsxs(StyledAlert, {
    ref: ref,
    ...rest,
    type: type,
    banner: banner,
    closable: closable,
    color: color,
    role: "alert",
    children: [iconNode ? /*#__PURE__*/_jsx(PrefixIcon, {
      children: iconNode
    }) : null, /*#__PURE__*/_jsx(Box, {
      flexGrow: 1,
      children: message
    }), closable ? /*#__PURE__*/_jsxs(CloseButton, {
      type: "button",
      onClick: handleClose,
      children: [/*#__PURE__*/_jsx(VisuallyHidden, {
        children: "Close"
      }), /*#__PURE__*/_jsx(CloseIcon, {
        "aria-hidden": true
      })]
    }) : null]
  });
});
if (process.env.NODE_ENV !== "production") {
  Alert.displayName = "Alert";
}