import { forwardRef } from "react";
import { useDisclosure, useCallbackRef } from "../hooks";
import { WarningIcon } from "../icons";
import { Popover } from "./popover";
import { FocusLock } from "./focus-lock";
import { Flex } from "./flex";
import { Box } from "./box";
import { Button } from "./button";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export const Popconfirm = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    title,
    disabled = false,
    trigger = "click",
    onConfirm,
    onCancel,
    okVariant = "primary",
    okText = "Ok",
    cancelText = "Cancel",
    icon,
    isOpen: isOpenProp,
    defaultIsOpen,
    onOpen,
    onClose,
    autoFocus = true,
    restoreFocus = true,
    initialFocusRef,
    finalFocusRef,
    children,
    ...rest
  } = _ref;
  const {
    isOpen,
    open,
    close
  } = useDisclosure({
    isOpen: isOpenProp,
    defaultIsOpen,
    onOpen,
    onClose
  });
  const handleOpen = () => {
    if (!disabled) {
      open();
    } else {
      onConfirm?.();
    }
  };
  const handleClose = () => {
    if (!disabled) {
      close();
    }
  };
  const handleCancel = event => {
    close();
    onCancel?.(event);
  };
  const handleConfirm = event => {
    close();
    onConfirm?.(event);
  };
  const onActivation = useCallbackRef(() => {
    initialFocusRef?.current?.focus();
  });
  const onDeactivation = useCallbackRef(() => {
    finalFocusRef?.current?.focus();
  });
  const content = /*#__PURE__*/_jsxs(FocusLock, {
    autoFocus: autoFocus,
    returnFocus: restoreFocus,
    onActivation: onActivation,
    onDeactivation: onDeactivation,
    children: [/*#__PURE__*/_jsxs(Flex, {
      gap: 2,
      pb: 2,
      alignItems: "flex-start",
      children: [/*#__PURE__*/_jsx(Box, {
        flex: "none",
        children: icon ?? /*#__PURE__*/_jsx(WarningIcon, {
          size: 18,
          display: "block",
          color: "warning.base"
        })
      }), /*#__PURE__*/_jsx(Box, {
        lineHeight: "base",
        color: "heading",
        children: title
      })]
    }), /*#__PURE__*/_jsxs(Flex, {
      gap: 2,
      justifyContent: "flex-end",
      children: [/*#__PURE__*/_jsx(Button, {
        size: "sm",
        onClick: handleCancel,
        children: cancelText
      }), /*#__PURE__*/_jsx(Button, {
        size: "sm",
        variant: okVariant,
        onClick: handleConfirm,
        children: okText
      })]
    })]
  });
  return /*#__PURE__*/_jsx(Popover, {
    ref: ref,
    p: 2,
    ...rest,
    isOpen: isOpen,
    onOpen: handleOpen,
    onClose: handleClose,
    trigger: trigger,
    content: content,
    children: children
  });
});
if (process.env.NODE_ENV !== "production") {
  Popconfirm.displayName = "Popconfirm";
}