import * as SwitchPrimitive from "@radix-ui/react-switch";
import { forwardRef } from "react";
import { margin } from "styled-system";
import styled from "styled-components";
import { Flex } from "./flex";
import { Spinner } from "./spinner";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
const SwitchSpinner = styled(Spinner).withConfig({
  displayName: "switch__SwitchSpinner",
  componentId: "sc-14us0id-0"
})(["position:relative;vertical-align:top;top:var(--thumb-margin);left:var(--thumb-margin);color:", ";width:14px;height:14px;"], p => p.theme.colors.alpha.black[5]);
const SwitchThumb = styled(SwitchPrimitive.Thumb).withConfig({
  displayName: "switch__SwitchThumb",
  componentId: "sc-14us0id-1"
})(["position:absolute;top:var(--thumb-margin);left:var(--thumb-margin);width:var(--thumb-size);height:var(--thumb-size);transition:all 0.2s ease-in-out;will-change:left;&::before{position:absolute;top:0;right:0;bottom:0;left:0;background:#fff;border-radius:100px;box-shadow:0 2px 4px 0 ", ";transition:all 0.2s ease-in-out;content:\"\";}"], p => p.theme.colors.shadow.base);
const SwitchContent = styled.span.withConfig({
  displayName: "switch__SwitchContent",
  componentId: "sc-14us0id-2"
})(["display:block;font-size:", "px;line-height:1;color:#fff;margin:0 7px 0 25px;transition:margin 0.2s;"], p => p.theme.fontSizes.sm);
const SwitchRoot = styled(SwitchPrimitive.Root).withConfig({
  displayName: "switch__SwitchRoot",
  componentId: "sc-14us0id-3"
})(["--thumb-size:18px;--thumb-margin:2px;all:unset;position:relative;display:inline-block;box-sizing:border-box;vertical-align:middle;border:0;border-radius:100px;min-width:44px;height:22px;line-height:22px;background:", ";transition:all 0.2s;user-select:none;cursor:pointer;", " &:not([data-disabled]):hover{background:", ";}&:focus{box-shadow:0 0 0 2px ", ";outline:0;}&[data-size=\"sm\"]{--thumb-size:12px;min-width:28px;height:16px;line-height:16px;", "{width:8px;height:8px;}", "{margin:0 5px 0 18px;}&[data-state=\"checked\"]{", "{margin:0 18px 0 5px;}}}&[data-state=\"unchecked\"] div[data-checked-content]{display:none;}&[data-state=\"checked\"] div[data-unchecked-content]{display:none;}&[data-state=\"checked\"]{background:", ";&:not([data-disabled]):hover{background:", ";}", "{left:calc(100% - var(--thumb-size) - var(--thumb-margin));}", "{color:", ";}", "{margin:0 25px 0 7px;}}&:not([data-disabled]):active{", "::before{right:-30%;left:0;}&[data-state=\"checked\"]{", "::before{right:0;left:-30%;}}}&[data-disabled]{opacity:0.4;cursor:not-allowed;*{box-shadow:none;cursor:not-allowed;}}"], p => p.theme.colors.disabled, margin, p => p.theme.colors.alpha[3], p => p.theme.colors.primary[2], SwitchSpinner, SwitchContent, SwitchContent, p => p.theme.colors.primary.base, p => p.theme.colors.primary.hover, SwitchThumb, SwitchSpinner, p => p.theme.colors.primary.base, SwitchContent, SwitchThumb, SwitchThumb);
export const Switch = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    size = "md",
    disabled,
    isLoading,
    onChange,
    checkedContent,
    uncheckedContent,
    ...rest
  } = _ref;
  return /*#__PURE__*/_jsxs(SwitchRoot, {
    ref: ref,
    ...rest,
    disabled: disabled || isLoading,
    onCheckedChange: onChange,
    "data-size": size,
    children: [/*#__PURE__*/_jsx(SwitchThumb, {
      children: isLoading ? /*#__PURE__*/_jsx(SwitchSpinner, {}) : null
    }), /*#__PURE__*/_jsxs(SwitchContent, {
      children: [/*#__PURE__*/_jsx(Flex, {
        "data-checked-content": true,
        children: checkedContent
      }), /*#__PURE__*/_jsx(Flex, {
        "data-unchecked-content": true,
        children: uncheckedContent
      })]
    })]
  });
});
if (process.env.NODE_ENV !== "production") {
  Switch.displayName = "Switch";
}