import { Children, isValidElement, cloneElement, forwardRef, useState } from "react";
import { useDisclosure, useForkRef, useEventListener } from "../hooks";
import { Box } from "./box";
import { Floater } from "./floater";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export const Tooltip = /*#__PURE__*/forwardRef((_ref, ref) => {
  let {
    title,
    placement = "top",
    mouseEnterDelay = 100,
    mouseLeaveDelay = 100,
    onOpen,
    onClose,
    children,
    ...rest
  } = _ref;
  const {
    isOpen,
    open,
    close,
    clearDelayTimer
  } = useDisclosure({
    onOpen,
    onClose
  });
  const openWithDelay = () => open({
    delay: mouseEnterDelay
  });
  const closeWithDelay = () => close({
    delay: mouseLeaveDelay
  });
  const [anchorNode, setAnchorNode] = useState(null);
  const child = Children.only(children);
  const childProps = {
    ref: useForkRef(child.ref, setAnchorNode)
  };
  const anchor = /*#__PURE__*/isValidElement(child) ? /*#__PURE__*/cloneElement(child, childProps) : child;
  useEventListener("mouseenter", openWithDelay, anchorNode);
  useEventListener("mouseleave", closeWithDelay, anchorNode);
  useEventListener("focus", openWithDelay, anchorNode);
  useEventListener("blur", closeWithDelay, anchorNode);
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [anchor, /*#__PURE__*/_jsx(Floater, {
      anchor: anchorNode,
      isOpen: isOpen,
      placement: placement,
      style: {
        pointerEvents: "none"
      },
      children: /*#__PURE__*/_jsx(Box, {
        ref: ref,
        p: 1,
        borderRadius: "base",
        boxShadow: "base",
        bg: "tooltip.bg",
        color: "tooltip.text",
        onMouseEnter: clearDelayTimer,
        onMouseLeave: closeWithDelay,
        ...rest,
        children: title
      })
    })]
  });
});
if (process.env.NODE_ENV !== "production") {
  Tooltip.displayName = "Tooltip";
}