import { useRef, useEffect } from "react";
import { useControllableState } from "./use-controllable-state";
import { useCallbackRef } from "./use-callback-ref";
/**
 * Uses boolean state with functions to open, close, and toggle.
 */
export function useDisclosure() {
  let {
    isOpen: isOpenProp,
    defaultIsOpen,
    onOpen,
    onClose
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  const [isOpen, setIsOpen] = useControllableState(isOpenProp, defaultIsOpen ?? false);
  const delayTimer = useRef(null);
  const clearDelayTimer = () => {
    clearTimeout(delayTimer.current);
    delayTimer.current = null;
  };
  useEffect(() => clearDelayTimer, []);
  const open = useCallbackRef(function () {
    let opt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    clearDelayTimer();
    const fn = () => {
      if (!isOpen) {
        setIsOpen(true);
        onOpen?.();
      }
    };
    if (opt.delay) {
      delayTimer.current = setTimeout(fn, opt.delay);
    } else {
      fn();
    }
  });
  const close = useCallbackRef(function () {
    let opt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    clearDelayTimer();
    const fn = () => {
      if (isOpen) {
        setIsOpen(false);
        onClose?.();
      }
    };
    if (opt.delay) {
      delayTimer.current = setTimeout(fn, opt.delay);
    } else {
      fn();
    }
  });
  const toggle = useCallbackRef(function () {
    let opt = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
    if (isOpen) {
      close(opt);
    } else {
      open(opt);
    }
  });
  return {
    isOpen,
    open,
    close,
    toggle,
    clearDelayTimer
  };
}