import { useCallback } from "react";

/**
 * Merges multiple event handlers into a single handler. Calling preventDefault() from any handler cancels the event,
 * meaning that execution of subsequent handlers will not occur.
 */
export function useForkHandler() {
  for (var _len = arguments.length, fns = new Array(_len), _key = 0; _key < _len; _key++) {
    fns[_key] = arguments[_key];
  }
  return useCallback(event => {
    fns.some(fn => {
      fn?.(event);
      return event?.defaultPrevented;
    });
  }, fns);
}